@@ -41,10 +41,14 @@ RELEASE_MAP = {
     'ocata': 'xenial',
     'pike': 'xenial',
     'queens': 'xenial',
+    'rocky': 'bionic',
+    'stein': 'bionic',
+    'train': 'bionic',
+    'ussuri': 'bionic',
 }
 MIRROR = "http://ubuntu-cloud.archive.canonical.com/ubuntu"
 UCA = "Ubuntu Cloud Archive"
-WEB_LINK = 'https://wiki.ubuntu.com/ServerTeam/CloudArchive'
+WEB_LINK = 'https://wiki.ubuntu.com/OpenStack/CloudArchive'
 APT_INSTALL_KEY = ['apt-get', '--quiet', '--assume-yes', 'install',
                    'ubuntu-cloud-keyring']
 
