@@ -22,6 +22,8 @@
 import os
 
 import apt
+import gi
+gi.require_version("Gtk", "3.0")
 from gi.repository import Gtk
 from gettext import gettext as _
 
