@@ -21,6 +21,8 @@
 #  USA
 
 import os
+import gi
+gi.require_version("Gtk", "3.0")
 from gi.repository import GObject, Gtk
 
 import aptdaemon.client
