@@ -702,13 +702,9 @@ class SoftwarePropertiesKDE(SoftwareProperties):
         messageBox.setIcon(QMessageBox.Information)
         reloadButton = messageBox.addButton(_("Reload"), QMessageBox.AcceptRole)
         messageBox.addButton(QMessageBox.Close)
-        text = _("<b><big>The information about available software is out-of-date</big></b>\n"
-               "\n"
-               "To install software and updates from newly added or changed sources, you "
-               "have to reload the information about available software.\n"
-               "\n"
-               "You need a working internet connection to continue.")
-        text = text.replace("\n", "<br />")
+        primary = _("Your local copy of the software catalog is out of date.")
+        secondary = _("A new copy will be downloaded.")
+        text = "%s<br /><br /><small>%s</small>" % (primary, secondary)
         messageBox.setText(text)
         messageBox.exec_()
         if (messageBox.clickedButton() == reloadButton):
@@ -732,7 +728,8 @@ class SoftwarePropertiesKDE(SoftwareProperties):
       res = cdrom.add(progress)
     except SystemError as msg:
       title = _("CD Error")
-      text = _("<big><b>Error scanning the CD</b></big>\n\n%s")%msg
+      primary = _("Error scanning the CD")
+      text = "%s\n\n<small>%s</small>" % (primary, msg)
       #KMessageBox.sorry(self.userinterface, text, title)
       QMessageBox.warning(self.userinterface, title, text)
       return
