@@ -5,6 +5,8 @@ from __future__ import print_function
 
 from gi.repository import GLib, Gio
 
+import apt_pkg
+
 import dbus
 import logging
 import glob
@@ -103,6 +105,9 @@ class TestDBus(unittest.TestCase):
 
     @classmethod
     def setUpClass(cls):
+        for k in apt_pkg.config.keys():
+            apt_pkg.config.clear(k)
+        apt_pkg.init()
         clear_apt_config()
         # create sources.list file
         create_sources_list()
